@@ -1,5 +1,5 @@
 from ....utils.code_utils import deprecate_module
 
-deprecate_module("ediFilesUtils", "edi_files_utils", "0.15.0")
+deprecate_module("ediFilesUtils", "edi_files_utils", "0.16.0", future_warn=True)
 
 from .edi_files_utils import *
