@@ -1,5 +1,5 @@
 from ....utils.code_utils import deprecate_module
 
-deprecate_module("plotDataTypes", "plot_data_types", "0.15.0")
+deprecate_module("plotDataTypes", "plot_data_types", "0.16.0", future_warn=True)
 
 from .plot_data_types import *
