@@ -1,38 +1,37 @@
 import numpy as np
 import properties
-from ....utils.code_utils import deprecate_class
+from ....utils.code_utils import deprecate_class, deprecate_property
 
 from .... import props
-from ....data import Data
 from ....utils import sdiag
+from ....data import Data
 
 from ..resistivity.fields_2d import Fields2D, Fields2DCellCentered, Fields2DNodal
 
 from ..resistivity.simulation_2d import BaseDCSimulation2D
 from ..resistivity import Simulation2DCellCentered as BaseSimulation2DCellCentered
 from ..resistivity import Simulation2DNodal as BaseSimulation2DNodal
-from ..resistivity import Survey
 
 
 class BaseIPSimulation2D(BaseDCSimulation2D):
 
-    sigma = props.PhysicalProperty("Electrical conductivity (S/m)")
-
-    rho = props.PhysicalProperty("Electrical resistivity (Ohm m)")
-
-    props.Reciprocal(sigma, rho)
-
     eta, etaMap, etaDeriv = props.Invertible("Electrical Chargeability (V/V)")
 
-    data_type = properties.StringChoice(
+    _data_type = properties.StringChoice(
         "IP data type", default="volt", choices=["volt", "apparent_chargeability"],
     )
 
+    data_type = deprecate_property(
+        _data_type, "data_type", new_name="receiver.data_type", removal_version="0.16.0"
+    )
+
     fieldsPair = Fields2D
     _Jmatrix = None
-    _f = None
-    sign = None
+    _f = None  # the DC fields
+    _sign = 1.0
     _pred = None
+    _scale = None
+    gtgdiag = None
 
     def fields(self, m):
         if self.verbose:
@@ -41,26 +40,18 @@ class BaseIPSimulation2D(BaseDCSimulation2D):
             # re-uses the DC simulation's fields method
             self._f = super().fields(None)
 
-            if self.verbose is True:
-                print(">> Data type is apparaent chargeability")
-
-            # call dpred function in 2D DC simulation
-            # set data type as volt ... for DC simulation
-            data_types = []
+        if self._scale is None:
+            scale = Data(self.survey, np.full(self.survey.nD, self._sign))
+            f = self.fields_to_space(self._f)
+            # loop through receievers to check if they need to set the _dc_voltage
             for src in self.survey.source_list:
                 for rx in src.receiver_list:
-                    data_types.append(rx.data_type)
-                    rx.data_type = "volt"
-
-            dc_voltage = super().dpred(m=[], f=self._f)
-            dc_data = Data(self.survey, dc_voltage)
-            icount = 0
-            for src in self.survey.source_list:
-                for rx in src.receiver_list:
-                    rx.data_type = data_types[icount]
-                    rx._dc_voltage = dc_data[src, rx]
-                    rx._Ps = {}
-                    icount += 1
+                    if (
+                        rx.data_type == "apparent_chargeability"
+                        or self._data_type == "apparent_chargeability"
+                    ):
+                        scale[src, rx] = self._sign / rx.eval(src, self.mesh, f)
+            self._scale = scale.dobs
 
         self._pred = self.forward(m, f=self._f)
 
@@ -68,11 +59,11 @@ class BaseIPSimulation2D(BaseDCSimulation2D):
 
     def dpred(self, m=None, f=None):
         """
-            Predicted data.
+        Predicted data.
 
-            .. math::
+        .. math::
 
-                d_\\text{pred} = Pf(m)
+            d_\\text{pred} = Pf(m)
 
         """
         # return self.Jvec(m, m, f=f)
@@ -81,20 +72,26 @@ class BaseIPSimulation2D(BaseDCSimulation2D):
 
         return self._pred
 
+    def getJtJdiag(self, m, W=None):
+        if self.gtgdiag is None:
+            J = self.getJ(m)
+            if W is None:
+                W = self._scale ** 2
+            else:
+                W = (self._scale * W.diagonal()) ** 2
+
+            self.gtgdiag = np.einsum("i,ij,ij->j", W, J, J)
+
+        return self.gtgdiag
+
     def Jvec(self, m, v, f=None):
-        self.model = m
-        J = self.getJ(m, f=f)
-        Jv = J.dot(v)
-        return self.sign * Jv
+        return self._scale * super().Jvec(m, v, f)
 
     def forward(self, m, f=None):
         return self.Jvec(m, m, f=f)
 
     def Jtvec(self, m, v, f=None):
-        self.model = m
-        J = self.getJ(m, f=f)
-        Jtv = J.T.dot(v)
-        return self.sign * Jtv
+        return super().Jtvec(m, v * self._scale, f)
 
     @property
     def deleteTheseOnModelUpdate(self):
@@ -140,7 +137,7 @@ class BaseIPSimulation2D(BaseDCSimulation2D):
     @property
     def MccRhoiDerivMat(self):
         """
-            Derivative of MccRho with respect to the model
+        Derivative of MccRho with respect to the model
         """
         if getattr(self, "_MccRhoiDerivMat", None) is None:
             rho = self.rho
@@ -151,7 +148,7 @@ class BaseIPSimulation2D(BaseDCSimulation2D):
 
     def MccRhoiDeriv(self, u, v, adjoint=False):
         """
-            Derivative of :code:`MccRhoi` with respect to the model.
+        Derivative of :code:`MccRhoi` with respect to the model.
         """
         if len(self.rho.shape) > 1:
             if self.rho.shape[1] > self.mesh.dim:
@@ -168,14 +165,14 @@ class BaseIPSimulation2D(BaseDCSimulation2D):
             rho = self.rho
             drho_dlogrho = sdiag(rho) * self.etaDeriv
             if adjoint:
-                return drho_dlogrho.T * (sdia(u * vol * (-1.0 / rho ** 2)) * v)
+                return drho_dlogrho.T * (sdiag(u * vol * (-1.0 / rho ** 2)) * v)
             else:
                 return sdiag(u * vol * (-1.0 / rho ** 2)) * (drho_dlogrho * v)
 
     @property
     def MnSigmaDerivMat(self):
         """
-            Derivative of MnSigma with respect to the model
+        Derivative of MnSigma with respect to the model
         """
         if getattr(self, "_MnSigmaDerivMat", None) is None:
             sigma = self.sigma
@@ -186,7 +183,7 @@ class BaseIPSimulation2D(BaseDCSimulation2D):
 
     def MnSigmaDeriv(self, u, v, adjoint=False):
         """
-            Derivative of MnSigma with respect to the model times a vector (u)
+        Derivative of MnSigma with respect to the model times a vector (u)
         """
         if self.storeInnerProduct:
             if adjoint:
@@ -213,10 +210,6 @@ class Simulation2DCellCentered(BaseIPSimulation2D, BaseSimulation2DCellCentered)
     _formulation = "HJ"  # CC potentials means J is on faces
     fieldsPair = Fields2DCellCentered
     bc_type = "Mixed"
-    sign = 1.0
-
-    def __init__(self, mesh, **kwargs):
-        BaseIPSimulation2D.__init__(self, mesh, **kwargs)
 
     def delete_these_for_sensitivity(self, sigma=None, rho=None):
         if self._Jmatrix is not None:
@@ -235,18 +228,18 @@ class Simulation2DCellCentered(BaseIPSimulation2D, BaseSimulation2DCellCentered)
         Derivative of MfRho with respect to the model
         """
         if getattr(self, "_MfRhoDerivMat", None) is None:
+            drho_dlogrho = sdiag(self.rho) * self.etaDeriv
             self._MfRhoDerivMat = (
                 self.mesh.getFaceInnerProductDeriv(np.ones(self.mesh.nC))(
                     np.ones(self.mesh.nF)
                 )
-                * sdiag(self.rho)
-                * self.etaDeriv
+                * drho_dlogrho
             )
         return self._MfRhoDerivMat
 
     def MfRhoIDeriv(self, u, v, adjoint=False):
         """
-            Derivative of :code:`MfRhoI` with respect to the model.
+        Derivative of :code:`MfRhoI` with respect to the model.
         """
         dMfRhoI_dI = -self.MfRhoI ** 2
         if self.storeInnerProduct:
@@ -271,10 +264,7 @@ class Simulation2DNodal(BaseIPSimulation2D, BaseSimulation2DNodal):
     _solutionType = "phiSolution"
     _formulation = "EB"  # CC potentials means J is on faces
     fieldsPair = Fields2DNodal
-    sign = -1.0
-
-    def __init__(self, mesh, **kwargs):
-        BaseIPSimulation2D.__init__(self, mesh, **kwargs)
+    _sign = -1.0
 
     def delete_these_for_sensitivity(self, sigma=None, rho=None):
         if self._Jmatrix is not None:
@@ -297,11 +287,11 @@ Simulation2DCellCentred = Simulation2DCellCentered
 ############
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class Problem2D_N(Simulation2DNodal):
     pass
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class Problem2D_CC(Simulation2DCellCentered):
     pass
