@@ -4,6 +4,7 @@ import properties
 from .... import survey
 from ....utils import Zero, closestPoints, mkvc
 from ....utils.code_utils import deprecate_property
+import warnings
 
 
 class BaseSrc(survey.BaseSrc):
@@ -40,7 +41,7 @@ class Dipole(BaseSrc):
         survey.SourceLocationArray("location of electrode"),
     )
     loc = deprecate_property(
-        location, "loc", new_name="location", removal_version="0.15.0"
+        location, "loc", new_name="location", removal_version="0.16.0", future_warn=True
     )
 
     def __init__(
@@ -52,8 +53,8 @@ class Dipole(BaseSrc):
             warnings.warn(
                 "The locationA property has been deprecated. Please set the "
                 "location_a property instead. This will be removed in version"
-                " 0.15.0 of SimPEG",
-                DeprecationWarning,
+                " 0.16.0 of SimPEG",
+                FutureWarning,
             )
 
         if "locationB" in kwargs.keys():
@@ -61,8 +62,8 @@ class Dipole(BaseSrc):
             warnings.warn(
                 "The locationB property has been deprecated. Please set the "
                 "location_b property instead. This will be removed in version"
-                " 0.15.0 of SimPEG",
-                DeprecationWarning,
+                " 0.16.0 of SimPEG",
+                FutureWarning,
             )
 
         # if location_a set, then use location_a, location_b
