@@ -77,7 +77,7 @@ class BaseTDEMSimulation(BaseTimeSimulation, BaseEMSimulation):
                 A = self.getAdiag(tInd)
                 if self.verbose:
                     print("Factoring...   (dt = {:e})".format(dt))
-                Ainv = self.Solver(A, **self.solver_opts)
+                Ainv = self.solver(A, **self.solver_opts)
                 if self.verbose:
                     print("Done")
 
@@ -161,7 +161,7 @@ class BaseTDEMSimulation(BaseTimeSimulation, BaseEMSimulation):
 
             if Adiaginv is None:
                 A = self.getAdiag(tInd)
-                Adiaginv = self.Solver(A, **self.solver_opts)
+                Adiaginv = self.solver(A, **self.solver_opts)
 
             Asubdiag = self.getAsubdiag(tInd)
 
@@ -307,7 +307,7 @@ class BaseTDEMSimulation(BaseTimeSimulation, BaseEMSimulation):
             # refactor if we need to
             if AdiagTinv is None:  # and tInd > -1:
                 Adiag = self.getAdiag(tInd)
-                AdiagTinv = self.Solver(Adiag.T, **self.solver_opts)
+                AdiagTinv = self.solver(Adiag.T, **self.solver_opts)
 
             if tInd < self.nT - 1:
                 Asubdiag = self.getAsubdiag(tInd + 1)
@@ -432,7 +432,7 @@ class BaseTDEMSimulation(BaseTimeSimulation, BaseEMSimulation):
             if self.verbose:
                 print("Factoring the system matrix for the DC problem")
             Adc = self.getAdc()
-            self._Adcinv = self.Solver(Adc)
+            self._Adcinv = self.solver(Adc)
         return self._Adcinv
 
 
@@ -674,7 +674,7 @@ class Simulation3DElectricField(BaseTDEMSimulation):
     def Jtvec(self, m, v, f=None):
 
         """
-            Jvec computes the adjoint of the sensitivity times a vector
+        Jvec computes the adjoint of the sensitivity times a vector
         """
 
         if f is None:
@@ -756,7 +756,7 @@ class Simulation3DElectricField(BaseTDEMSimulation):
             # refactor if we need to
             if AdiagTinv is None:  # and tInd > -1:
                 Adiag = self.getAdiag(tInd)
-                AdiagTinv = self.Solver(Adiag.T, **self.solver_opts)
+                AdiagTinv = self.solver(Adiag.T, **self.solver_opts)
 
             if tInd < self.nT - 1:
                 Asubdiag = self.getAsubdiag(tInd + 1)
@@ -1148,21 +1148,21 @@ class Simulation3DCurrentDensity(BaseTDEMSimulation):
 ############
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class Problem3D_e(Simulation3DElectricField):
     pass
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class Problem3D_b(Simulation3DMagneticFluxDensity):
     pass
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class Problem3D_h(Simulation3DMagneticField):
     pass
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class Problem3D_j(Simulation3DCurrentDensity):
     pass
