@@ -119,7 +119,7 @@ class Simulation3DIntegral(BasePFSimulation):
     @property
     def nD(self):
         """
-            Number of data
+        Number of data
         """
         self._nD = self.survey.receiver_locations.shape[0]
 
@@ -140,12 +140,12 @@ class Simulation3DIntegral(BasePFSimulation):
 
     def getJtJdiag(self, m, W=None):
         """
-            Return the diagonal of JtJ
+        Return the diagonal of JtJ
         """
         self.model = m
 
         if W is None:
-            W = np.ones(self.nD)
+            W = np.ones(self.survey.nD)
         else:
             W = W.diagonal() ** 2
         if getattr(self, "_gtg_diagonal", None) is None:
@@ -171,8 +171,7 @@ class Simulation3DIntegral(BasePFSimulation):
         return mkvc((sdiag(np.sqrt(diag)) @ self.chiDeriv).power(2).sum(axis=0))
 
     def Jvec(self, m, v, f=None):
-        if self.chi is None:
-            self.model = np.zeros(self.G.shape[1])
+        self.model = m
         dmu_dm_v = self.chiDeriv @ v
 
         Jvec = self.G @ dmu_dm_v.astype(np.float32)
@@ -185,8 +184,7 @@ class Simulation3DIntegral(BasePFSimulation):
             return Jvec
 
     def Jtvec(self, m, v, f=None):
-        if self.chi is None:
-            self.model = np.zeros(self.G.shape[1])
+        self.model = m
 
         if self.is_amplitude_data:
             v = (self.fieldDeriv * v).T.reshape(-1)
@@ -196,8 +194,8 @@ class Simulation3DIntegral(BasePFSimulation):
     @property
     def fieldDeriv(self):
 
-        if self.chi is None:
-            self.model = np.zeros(self.G.shape[1])
+        if getattr(self, "chi", None) is None:
+            self.model = np.zeros(self.chiMap.nP)
 
         if getattr(self, "_fieldDeriv", None) is None:
             fields = np.asarray(self.G.dot((self.chiMap @ self.chi).astype(np.float32)))
@@ -210,7 +208,7 @@ class Simulation3DIntegral(BasePFSimulation):
     @classmethod
     def normalized_fields(cls, fields):
         """
-            Return the normalized B fields
+        Return the normalized B fields
         """
 
         # Get field amplitude
@@ -221,7 +219,7 @@ class Simulation3DIntegral(BasePFSimulation):
     @classmethod
     def compute_amplitude(cls, b_xyz):
         """
-            Compute amplitude of the magnetic field
+        Compute amplitude of the magnetic field
         """
 
         amplitude = np.linalg.norm(b_xyz.reshape((3, -1), order="F"), axis=0)
@@ -230,25 +228,25 @@ class Simulation3DIntegral(BasePFSimulation):
 
     def evaluate_integral(self, receiver_location, components):
         """
-            Load in the active nodes of a tensor mesh and computes the magnetic
-            forward relation between a cuboid and a given observation
-            location outside the Earth [obsx, obsy, obsz]
+        Load in the active nodes of a tensor mesh and computes the magnetic
+        forward relation between a cuboid and a given observation
+        location outside the Earth [obsx, obsy, obsz]
 
-            INPUT:
-            receiver_location:  [obsx, obsy, obsz] nC x 3 Array
+        INPUT:
+        receiver_location:  [obsx, obsy, obsz] nC x 3 Array
 
-            components: list[str]
-                List of magnetic components chosen from:
-                'bx', 'by', 'bz', 'bxx', 'bxy', 'bxz', 'byy', 'byz', 'bzz'
+        components: list[str]
+            List of magnetic components chosen from:
+            'bx', 'by', 'bz', 'bxx', 'bxy', 'bxz', 'byy', 'byz', 'bzz'
 
-            OUTPUT:
-            Tx = [Txx Txy Txz]
-            Ty = [Tyx Tyy Tyz]
-            Tz = [Tzx Tzy Tzz]
+        OUTPUT:
+        Tx = [Txx Txy Txz]
+        Ty = [Tyx Tyy Tyz]
+        Tz = [Tzx Tzy Tzz]
         """
         # TODO: This should probably be converted to C
-        tol1 = 1e-10    # Tolerance 1 for numerical stability over nodes and edges
-        tol2 = 1e-4     # Tolerance 2 for numerical stability over nodes and edges
+        tol1 = 1e-10  # Tolerance 1 for numerical stability over nodes and edges
+        tol2 = 1e-4  # Tolerance 2 for numerical stability over nodes and edges
 
         rows = {component: np.zeros(3 * self.Xn.shape[0]) for component in components}
 
@@ -256,24 +254,28 @@ class Simulation3DIntegral(BasePFSimulation):
         nC = self.Xn.shape[0]
 
         # base cell dimensions
-        min_hx, min_hy, min_hz = self.mesh.hx.min(), self.mesh.hy.min(), self.mesh.hz.min()
+        min_hx, min_hy, min_hz = (
+            self.mesh.hx.min(),
+            self.mesh.hy.min(),
+            self.mesh.hz.min(),
+        )
 
         # comp. pos. differences for tne, bsw nodes. Adjust if location within
         # tolerance of a node or edge
         dz2 = self.Zn[:, 1] - receiver_location[2]
-        dz2[np.abs(dz2)/min_hz < tol2] = tol2 * min_hz
+        dz2[np.abs(dz2) / min_hz < tol2] = tol2 * min_hz
         dz1 = self.Zn[:, 0] - receiver_location[2]
-        dz1[np.abs(dz1)/min_hz < tol2] = tol2 * min_hz
+        dz1[np.abs(dz1) / min_hz < tol2] = tol2 * min_hz
 
         dy2 = self.Yn[:, 1] - receiver_location[1]
-        dy2[np.abs(dy2)/min_hy < tol2] = tol2 * min_hy
+        dy2[np.abs(dy2) / min_hy < tol2] = tol2 * min_hy
         dy1 = self.Yn[:, 0] - receiver_location[1]
-        dy1[np.abs(dy1)/min_hy < tol2] = tol2 * min_hy
+        dy1[np.abs(dy1) / min_hy < tol2] = tol2 * min_hy
 
         dx2 = self.Xn[:, 1] - receiver_location[0]
-        dx2[np.abs(dx2)/min_hx < tol2] = tol2 * min_hx
+        dx2[np.abs(dx2) / min_hx < tol2] = tol2 * min_hx
         dx1 = self.Xn[:, 0] - receiver_location[0]
-        dx1[np.abs(dx1)/min_hx < tol2] = tol2 * min_hx
+        dx1[np.abs(dx1) / min_hx < tol2] = tol2 * min_hx
 
         # comp. squared diff
         dx2dx2 = dx2 ** 2.0
@@ -657,7 +659,7 @@ class Simulation3DIntegral(BasePFSimulation):
 
 class Simulation3DDifferential(BaseSimulation):
     """
-        Secondary field approach using differential equations!
+    Secondary field approach using differential equations!
     """
 
     # surveyPair = MAG.BaseMagSurvey
@@ -747,15 +749,15 @@ class Simulation3DDifferential(BaseSimulation):
 
     def fields(self, m):
         """
-            Return magnetic potential (u) and flux (B)
-            u: defined on the cell center [nC x 1]
-            B: defined on the cell center [nG x 1]
+        Return magnetic potential (u) and flux (B)
+        u: defined on the cell center [nC x 1]
+        B: defined on the cell center [nG x 1]
 
-            After we compute u, then we update B.
+        After we compute u, then we update B.
 
-            .. math ::
+        .. math ::
 
-                \mathbf{B}_s = (\MfMui)^{-1}\mathbf{M}^f_{\mu_0^{-1}}\mathbf{B}_0-\mathbf{B}_0 -(\MfMui)^{-1}\Div^T \mathbf{u}
+            \mathbf{B}_s = (\MfMui)^{-1}\mathbf{M}^f_{\mu_0^{-1}}\mathbf{B}_0-\mathbf{B}_0 -(\MfMui)^{-1}\Div^T \mathbf{u}
 
         """
         self.makeMassMatrices(m)
@@ -1010,20 +1012,20 @@ class Simulation3DDifferential(BaseSimulation):
 
     def projectFields(self, u):
         """
-            This function projects the fields onto the data space.
-            Especially, here for we use total magnetic intensity (TMI) data,
-            which is common in practice.
-            First we project our B on to data location
+        This function projects the fields onto the data space.
+        Especially, here for we use total magnetic intensity (TMI) data,
+        which is common in practice.
+        First we project our B on to data location
 
-            .. math::
+        .. math::
 
-                \mathbf{B}_{rec} = \mathbf{P} \mathbf{B}
+            \mathbf{B}_{rec} = \mathbf{P} \mathbf{B}
 
-            then we take the dot product between B and b_0
+        then we take the dot product between B and b_0
 
-            .. math ::
+        .. math ::
 
-                \\text{TMI} = \\vec{B}_s \cdot \hat{B}_0
+            \\text{TMI} = \\vec{B}_s \cdot \hat{B}_0
 
         """
         # TODO: There can be some different tyes of data like |B| or B
@@ -1054,13 +1056,13 @@ class Simulation3DDifferential(BaseSimulation):
     @utils.count
     def projectFieldsDeriv(self, B):
         """
-            This function projects the fields onto the data space.
+        This function projects the fields onto the data space.
 
-            .. math::
+        .. math::
 
-                \\frac{\partial d_\\text{pred}}{\partial \mathbf{B}} = \mathbf{P}
+            \\frac{\partial d_\\text{pred}}{\partial \mathbf{B}} = \mathbf{P}
 
-            Especially, this function is for TMI data type
+        Especially, this function is for TMI data type
         """
 
         components = self.survey.components
@@ -1098,7 +1100,7 @@ class Simulation3DDifferential(BaseSimulation):
 
 def MagneticsDiffSecondaryInv(mesh, model, data, **kwargs):
     """
-        Inversion module for MagneticsDiffSecondary
+    Inversion module for MagneticsDiffSecondary
 
     """
     from SimPEG import Optimization, Regularization, Parameters, ObjFunction, Inversion
@@ -1126,11 +1128,11 @@ def MagneticsDiffSecondaryInv(mesh, model, data, **kwargs):
 ############
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class MagneticIntegral(Simulation3DIntegral):
     pass
 
 
-@deprecate_class(removal_version="0.15.0")
+@deprecate_class(removal_version="0.16.0", future_warn=True)
 class Problem3D_Diff(Simulation3DDifferential):
     pass
