@@ -10,3 +10,11 @@ from .tikhonov import (
     Tikhonov,
 )
 from .sparse import SparseSmall, SparseDeriv, Sparse
+from .pgi import (
+    SimplePGIsmallness,
+    PGIsmallness,
+    SimplePGI,
+    PGI,
+    SimplePGIwithNonlinearRelationshipsSmallness,
+    SimplePGIwithRelationships,
+)
