@@ -1,5 +1,5 @@
 from .code_utils import deprecate_module
 
-deprecate_module("matutils", "mat_utils", "0.15.0")
+deprecate_module("matutils", "mat_utils", "0.16.0", future_warn=True)
 
 from .mat_utils import *
