@@ -223,7 +223,7 @@ def surface2ind_topo(mesh, topo, gridLoc="CC", method="nearest", fill_value=np.n
 
 def surface_layer_index(mesh, topo, index=0):
     """
-        Find the ith layer below topo
+    Find the ith layer below topo
     """
 
     actv = np.zeros(mesh.nC, dtype="bool")
@@ -258,3 +258,71 @@ def surface_layer_index(mesh, topo, index=0):
     actv[inds] = True
 
     return actv
+
+
+def depth_weighting(mesh, reference_locs, indActive=None, exponent=2.0, threshold=None):
+    """ A simple depth weighting function
+
+    This function is a simple form of depth weighting based off of the vertical distance
+    of mesh cell centers from the reference location(s).
+
+    This is commonly used to counteract the natural decay of potential field data at
+    depth.
+
+    Parameters
+    ----------
+    mesh : discretize.base.BaseMesh
+        discretize model space.
+    reference_locs : float or (N, dim) numpy.ndarray
+        the reference values for top of the points
+    indActive : (mesh.n_cells) numpy.ndarray of bool, optional
+        index vector for the active cells on the mesh.
+        A value of `None` implies every cell is active.
+    exponent : float, optional
+        exponent parameter for depth weighting.
+    threshold : float, optional
+        The default value is half of the smallest cell width.
+
+    Returns
+    -------
+    wz : (n_active) numpy.ndarray
+        Normalized depth weights for the mesh, at every active cell.
+
+    Notes
+    -----
+    When ``reference_locs`` is a single value the function is defined as,
+
+    >>> wz = (np.abs(mesh.cell_centers[:, -1] - reference_locs) + threshold) ** (-0.5 * exponent)
+
+    When ``reference_locs`` is an array of values, the difference is between the
+    nearest point (of first two dimensions) in ``reference_locs``.
+    'exponent' and 'threshold' are two adjustable parameters.
+    """
+
+    # Default threshold value
+    if threshold is None:
+        threshold = 0.5 * mesh.h_gridded.min()
+
+    reference_locs = np.asarray(reference_locs)
+
+    # Calculate depth from receiver locations, delta_z
+    # reference_locs is a scalar
+    if reference_locs.ndim < 2:
+        delta_z = np.abs(mesh.cell_centers[:, -1] - reference_locs)
+
+    # reference_locs is a 2d array
+    elif reference_locs.ndim == 2:
+
+        tree = cKDTree(reference_locs[:, :-1])
+        _, ind = tree.query(mesh.cell_centers[:, :-1])
+        delta_z = np.abs(mesh.cell_centers[:, -1] - reference_locs[ind, -1])
+
+    else:
+        raise ValueError("reference_locs must be either a scalar or 2d array!")
+
+    wz = (delta_z + threshold) ** (-0.5 * exponent)
+
+    if indActive is not None:
+        wz = wz[indActive]
+
+    return wz / np.nanmax(wz)
